extract_request_credentials

Function extract_request_credentials 

pub fn extract_request_credentials(
    headers: &HeaderMap,
    header_location: &str,
    header_name: &str,
) -> Result<RequestCredentials, ExtractError>
Extracts the credential value for the active auth method’s declared location (AuthManager::header_location/header_location_for) off an incoming HTTP request. The extracted value is relayed verbatim to the facaded API — whatever the caller sent, prefixed or not.