pub fn get_operation(conn: &Connection, operation_id: &str) -> Result<Value>Expand description
Returns the literal schema, path, method, and documentation for a specific operationId (PRD 1.5).
pub fn get_operation(conn: &Connection, operation_id: &str) -> Result<Value>Returns the literal schema, path, method, and documentation for a specific operationId (PRD 1.5).