Enums
Functions
- extract_
request_ credentials - Extracts the credential value for the active auth method’s declared
location (
AuthManager::header_location/header_location_for) off an incoming HTTP request. The extracted value is relayed verbatim to the facaded API — whatever the caller sent, prefixed or not.